from typing import Literal

Rotate = Literal[
    '0',
    '1',
    '2',
    '3',
    '6',
    '12',
    '45',
    '90',
    '180',
]
